Class: PulpContainerClient::ContainerContainerRepositoryResponse
- Inherits:
-
Object
- Object
- PulpContainerClient::ContainerContainerRepositoryResponse
- Defined in:
- lib/pulp_container_client/models/container_container_repository_response.rb
Overview
Serializer for Container Repositories.
Instance Attribute Summary collapse
-
#description ⇒ Object
An optional description.
-
#latest_version_href ⇒ Object
Returns the value of attribute latest_version_href.
-
#manifest_signing_service ⇒ Object
A reference to an associated signing service.
-
#name ⇒ Object
A unique name for this repository.
-
#prn ⇒ Object
The Pulp Resource Name (PRN).
-
#pulp_created ⇒ Object
Timestamp of creation.
-
#pulp_href ⇒ Object
Returns the value of attribute pulp_href.
-
#pulp_labels ⇒ Object
Returns the value of attribute pulp_labels.
-
#pulp_last_updated ⇒ Object
Timestamp of the last time this resource was updated.
-
#remote ⇒ Object
An optional remote to use by default when syncing.
-
#retain_checkpoints ⇒ Object
Retain X checkpoint publications for the repository.
-
#retain_repo_versions ⇒ Object
Retain X versions of the repository.
-
#versions_href ⇒ Object
Returns the value of attribute versions_href.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ContainerContainerRepositoryResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ContainerContainerRepositoryResponse
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 110 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PulpContainerClient::ContainerContainerRepositoryResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PulpContainerClient::ContainerContainerRepositoryResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pulp_href') self.pulp_href = attributes[:'pulp_href'] end if attributes.key?(:'prn') self.prn = attributes[:'prn'] end if attributes.key?(:'pulp_created') self.pulp_created = attributes[:'pulp_created'] end if attributes.key?(:'pulp_last_updated') self.pulp_last_updated = attributes[:'pulp_last_updated'] end if attributes.key?(:'versions_href') self.versions_href = attributes[:'versions_href'] end if attributes.key?(:'pulp_labels') if (value = attributes[:'pulp_labels']).is_a?(Hash) self.pulp_labels = value end end if attributes.key?(:'latest_version_href') self.latest_version_href = attributes[:'latest_version_href'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'retain_repo_versions') self.retain_repo_versions = attributes[:'retain_repo_versions'] end if attributes.key?(:'retain_checkpoints') self.retain_checkpoints = attributes[:'retain_checkpoints'] end if attributes.key?(:'remote') self.remote = attributes[:'remote'] end if attributes.key?(:'manifest_signing_service') self.manifest_signing_service = attributes[:'manifest_signing_service'] end end |
Instance Attribute Details
#description ⇒ Object
An optional description.
40 41 42 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 40 def description @description end |
#latest_version_href ⇒ Object
Returns the value of attribute latest_version_href.
34 35 36 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 34 def latest_version_href @latest_version_href end |
#manifest_signing_service ⇒ Object
A reference to an associated signing service.
52 53 54 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 52 def manifest_signing_service @manifest_signing_service end |
#name ⇒ Object
A unique name for this repository.
37 38 39 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 37 def name @name end |
#prn ⇒ Object
The Pulp Resource Name (PRN).
22 23 24 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 22 def prn @prn end |
#pulp_created ⇒ Object
Timestamp of creation.
25 26 27 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 25 def pulp_created @pulp_created end |
#pulp_href ⇒ Object
Returns the value of attribute pulp_href.
19 20 21 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 19 def pulp_href @pulp_href end |
#pulp_labels ⇒ Object
Returns the value of attribute pulp_labels.
32 33 34 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 32 def pulp_labels @pulp_labels end |
#pulp_last_updated ⇒ Object
Timestamp of the last time this resource was updated. Note: for immutable resources - like content, repository versions, and publication - pulp_created and pulp_last_updated dates will be the same.
28 29 30 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 28 def pulp_last_updated @pulp_last_updated end |
#remote ⇒ Object
An optional remote to use by default when syncing.
49 50 51 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 49 def remote @remote end |
#retain_checkpoints ⇒ Object
Retain X checkpoint publications for the repository. Default is null which retains all checkpoints.
46 47 48 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 46 def retain_checkpoints @retain_checkpoints end |
#retain_repo_versions ⇒ Object
Retain X versions of the repository. Default is null which retains all versions.
43 44 45 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 43 def retain_repo_versions @retain_repo_versions end |
#versions_href ⇒ Object
Returns the value of attribute versions_href.
30 31 32 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 30 def versions_href @versions_href end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 289 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PulpContainerClient.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
74 75 76 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 74 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 55 def self.attribute_map { :'pulp_href' => :'pulp_href', :'prn' => :'prn', :'pulp_created' => :'pulp_created', :'pulp_last_updated' => :'pulp_last_updated', :'versions_href' => :'versions_href', :'pulp_labels' => :'pulp_labels', :'latest_version_href' => :'latest_version_href', :'name' => :'name', :'description' => :'description', :'retain_repo_versions' => :'retain_repo_versions', :'retain_checkpoints' => :'retain_checkpoints', :'remote' => :'remote', :'manifest_signing_service' => :'manifest_signing_service' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 265 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 102 103 104 105 106 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 98 def self.openapi_nullable Set.new([ :'description', :'retain_repo_versions', :'retain_checkpoints', :'remote', :'manifest_signing_service' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 79 def self.openapi_types { :'pulp_href' => :'String', :'prn' => :'String', :'pulp_created' => :'Time', :'pulp_last_updated' => :'Time', :'versions_href' => :'String', :'pulp_labels' => :'Hash<String, String>', :'latest_version_href' => :'String', :'name' => :'String', :'description' => :'String', :'retain_repo_versions' => :'Integer', :'retain_checkpoints' => :'Integer', :'remote' => :'String', :'manifest_signing_service' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 232 def ==(o) return true if self.equal?(o) self.class == o.class && pulp_href == o.pulp_href && prn == o.prn && pulp_created == o.pulp_created && pulp_last_updated == o.pulp_last_updated && versions_href == o.versions_href && pulp_labels == o.pulp_labels && latest_version_href == o.latest_version_href && name == o.name && description == o.description && retain_repo_versions == o.retain_repo_versions && retain_checkpoints == o.retain_checkpoints && remote == o.remote && manifest_signing_service == o.manifest_signing_service end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
360 361 362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 360 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
252 253 254 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 252 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
258 259 260 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 258 def hash [pulp_href, prn, pulp_created, pulp_last_updated, versions_href, pulp_labels, latest_version_href, name, description, retain_repo_versions, retain_checkpoints, remote, manifest_signing_service].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 182 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if !@retain_repo_versions.nil? && @retain_repo_versions < 1 invalid_properties.push('invalid value for "retain_repo_versions", must be greater than or equal to 1.') end if !@retain_checkpoints.nil? && @retain_checkpoints < 1 invalid_properties.push('invalid value for "retain_checkpoints", must be greater than or equal to 1.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
336 337 338 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 336 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 342 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
330 331 332 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 330 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
202 203 204 205 206 207 208 |
# File 'lib/pulp_container_client/models/container_container_repository_response.rb', line 202 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if !@retain_repo_versions.nil? && @retain_repo_versions < 1 return false if !@retain_checkpoints.nil? && @retain_checkpoints < 1 true end |