Class: PulpContainerClient::ContainerManifestResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/pulp_container_client/models/container_manifest_response.rb

Overview

Serializer for Manifests.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ContainerManifestResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 133

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PulpContainerClient::ContainerManifestResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PulpContainerClient::ContainerManifestResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pulp_href')
    self.pulp_href = attributes[:'pulp_href']
  end

  if attributes.key?(:'prn')
    self.prn = attributes[:'prn']
  end

  if attributes.key?(:'pulp_created')
    self.pulp_created = attributes[:'pulp_created']
  end

  if attributes.key?(:'pulp_last_updated')
    self.pulp_last_updated = attributes[:'pulp_last_updated']
  end

  if attributes.key?(:'digest')
    self.digest = attributes[:'digest']
  else
    self.digest = nil
  end

  if attributes.key?(:'schema_version')
    self.schema_version = attributes[:'schema_version']
  else
    self.schema_version = nil
  end

  if attributes.key?(:'media_type')
    self.media_type = attributes[:'media_type']
  else
    self.media_type = nil
  end

  if attributes.key?(:'listed_manifests')
    if (value = attributes[:'listed_manifests']).is_a?(Array)
      self.listed_manifests = value
    end
  else
    self.listed_manifests = nil
  end

  if attributes.key?(:'config_blob')
    self.config_blob = attributes[:'config_blob']
  end

  if attributes.key?(:'blobs')
    if (value = attributes[:'blobs']).is_a?(Array)
      self.blobs = value
    end
  else
    self.blobs = nil
  end

  if attributes.key?(:'annotations')
    self.annotations = attributes[:'annotations']
  end

  if attributes.key?(:'labels')
    self.labels = attributes[:'labels']
  end

  if attributes.key?(:'is_bootable')
    self.is_bootable = attributes[:'is_bootable']
  else
    self.is_bootable = false
  end

  if attributes.key?(:'is_flatpak')
    self.is_flatpak = attributes[:'is_flatpak']
  else
    self.is_flatpak = false
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'architecture')
    self.architecture = attributes[:'architecture']
  end

  if attributes.key?(:'os')
    self.os = attributes[:'os']
  end

  if attributes.key?(:'compressed_image_size')
    self.compressed_image_size = attributes[:'compressed_image_size']
  end
end

Instance Attribute Details

#annotationsObject

Property that contains arbitrary metadata stored inside the image manifest.



49
50
51
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 49

def annotations
  @annotations
end

#architectureObject

The CPU architecture which the binaries in this image are built to run on.



64
65
66
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 64

def architecture
  @architecture
end

#blobsObject

Blobs that are referenced by this Manifest



46
47
48
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 46

def blobs
  @blobs
end

#compressed_image_sizeObject

Specifies the sum of the sizes, in bytes, of all compressed layers



70
71
72
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 70

def compressed_image_size
  @compressed_image_size
end

#config_blobObject

Blob that contains configuration for this Manifest



43
44
45
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 43

def config_blob
  @config_blob
end

#digestObject

sha256 of the Manifest file



31
32
33
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 31

def digest
  @digest
end

#is_bootableObject

A boolean determining whether users can boot from an image or not. check type field instead



55
56
57
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 55

def is_bootable
  @is_bootable
end

#is_flatpakObject

A boolean determining whether the image bundles a Flatpak application. check type field instead



58
59
60
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 58

def is_flatpak
  @is_flatpak
end

#labelsObject

Property describing metadata stored inside the image configuration



52
53
54
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 52

def labels
  @labels
end

#listed_manifestsObject

Manifests that are referenced by this Manifest List



40
41
42
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 40

def listed_manifests
  @listed_manifests
end

#media_typeObject

Manifest media type of the file



37
38
39
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 37

def media_type
  @media_type
end

#osObject

The name of the operating system which the image is built to run on.



67
68
69
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 67

def os
  @os
end

#prnObject

The Pulp Resource Name (PRN).



22
23
24
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 22

def prn
  @prn
end

#pulp_createdObject

Timestamp of creation.



25
26
27
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 25

def pulp_created
  @pulp_created
end

#pulp_hrefObject

Returns the value of attribute pulp_href.



19
20
21
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 19

def pulp_href
  @pulp_href
end

#pulp_last_updatedObject

Timestamp of the last time this resource was updated. Note: for immutable resources - like content, repository versions, and publication - pulp_created and pulp_last_updated dates will be the same.



28
29
30
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 28

def pulp_last_updated
  @pulp_last_updated
end

#schema_versionObject

Manifest schema version



34
35
36
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 34

def schema_version
  @schema_version
end

#typeObject

Manifest type (flatpak, bootable, signature, etc.).



61
62
63
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 61

def type
  @type
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 341

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = PulpContainerClient.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



97
98
99
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 97

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 73

def self.attribute_map
  {
    :'pulp_href' => :'pulp_href',
    :'prn' => :'prn',
    :'pulp_created' => :'pulp_created',
    :'pulp_last_updated' => :'pulp_last_updated',
    :'digest' => :'digest',
    :'schema_version' => :'schema_version',
    :'media_type' => :'media_type',
    :'listed_manifests' => :'listed_manifests',
    :'config_blob' => :'config_blob',
    :'blobs' => :'blobs',
    :'annotations' => :'annotations',
    :'labels' => :'labels',
    :'is_bootable' => :'is_bootable',
    :'is_flatpak' => :'is_flatpak',
    :'type' => :'type',
    :'architecture' => :'architecture',
    :'os' => :'os',
    :'compressed_image_size' => :'compressed_image_size'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 317

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



126
127
128
129
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 126

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 102

def self.openapi_types
  {
    :'pulp_href' => :'String',
    :'prn' => :'String',
    :'pulp_created' => :'Time',
    :'pulp_last_updated' => :'Time',
    :'digest' => :'String',
    :'schema_version' => :'Integer',
    :'media_type' => :'String',
    :'listed_manifests' => :'Array<String>',
    :'config_blob' => :'String',
    :'blobs' => :'Array<String>',
    :'annotations' => :'Object',
    :'labels' => :'Object',
    :'is_bootable' => :'Boolean',
    :'is_flatpak' => :'Boolean',
    :'type' => :'String',
    :'architecture' => :'String',
    :'os' => :'String',
    :'compressed_image_size' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 279

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pulp_href == o.pulp_href &&
      prn == o.prn &&
      pulp_created == o.pulp_created &&
      pulp_last_updated == o.pulp_last_updated &&
      digest == o.digest &&
      schema_version == o.schema_version &&
      media_type == o.media_type &&
      listed_manifests == o.listed_manifests &&
      config_blob == o.config_blob &&
      blobs == o.blobs &&
      annotations == o.annotations &&
      labels == o.labels &&
      is_bootable == o.is_bootable &&
      is_flatpak == o.is_flatpak &&
      type == o.type &&
      architecture == o.architecture &&
      os == o.os &&
      compressed_image_size == o.compressed_image_size
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



412
413
414
415
416
417
418
419
420
421
422
423
424
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 412

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


304
305
306
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 304

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



310
311
312
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 310

def hash
  [pulp_href, prn, pulp_created, pulp_last_updated, digest, schema_version, media_type, listed_manifests, config_blob, blobs, annotations, labels, is_bootable, is_flatpak, type, architecture, os, compressed_image_size].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 239

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @digest.nil?
    invalid_properties.push('invalid value for "digest", digest cannot be nil.')
  end

  if @schema_version.nil?
    invalid_properties.push('invalid value for "schema_version", schema_version cannot be nil.')
  end

  if @media_type.nil?
    invalid_properties.push('invalid value for "media_type", media_type cannot be nil.')
  end

  if @listed_manifests.nil?
    invalid_properties.push('invalid value for "listed_manifests", listed_manifests cannot be nil.')
  end

  if @blobs.nil?
    invalid_properties.push('invalid value for "blobs", blobs cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



388
389
390
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 388

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



394
395
396
397
398
399
400
401
402
403
404
405
406
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 394

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



382
383
384
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 382

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



267
268
269
270
271
272
273
274
275
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 267

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @digest.nil?
  return false if @schema_version.nil?
  return false if @media_type.nil?
  return false if @listed_manifests.nil?
  return false if @blobs.nil?
  true
end