Class: PulpContainerClient::RepositoriesContainerApi
- Inherits:
-
Object
- Object
- PulpContainerClient::RepositoriesContainerApi
- Defined in:
- lib/pulp_container_client/api/repositories_container_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#add(container_repository_href, data, opts = {}) ⇒ AsyncOperationResponse
Add content Trigger an asynchronous task to recursively add container content.
-
#add_with_http_info(container_repository_href, data, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Add content Trigger an asynchronous task to recursively add container content.
-
#build_image(container_repository_href, opts = {}) ⇒ AsyncOperationResponse
Build an Image Trigger an asynchronous task to build an OCI image from a Containerfile.
-
#build_image_with_http_info(container_repository_href, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Build an Image Trigger an asynchronous task to build an OCI image from a Containerfile.
-
#copy_manifests(container_repository_href, data, opts = {}) ⇒ AsyncOperationResponse
Copy manifests Trigger an asynchronous task to copy manifests.
-
#copy_manifests_with_http_info(container_repository_href, data, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Copy manifests Trigger an asynchronous task to copy manifests.
-
#copy_tags(container_repository_href, data, opts = {}) ⇒ AsyncOperationResponse
Copy tags Trigger an asynchronous task to copy tags.
-
#copy_tags_with_http_info(container_repository_href, data, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Copy tags Trigger an asynchronous task to copy tags.
-
#create(data, opts = {}) ⇒ ContainerContainerRepository
Create a container repository ViewSet for container repo.
-
#create_with_http_info(data, opts = {}) ⇒ Array<(ContainerContainerRepository, Integer, Hash)>
Create a container repository ViewSet for container repo.
-
#delete(container_repository_href, opts = {}) ⇒ AsyncOperationResponse
Delete a container repository Trigger an asynchronous task to delete a repository.
-
#delete_with_http_info(container_repository_href, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Delete a container repository Trigger an asynchronous task to delete a repository.
-
#initialize(api_client = ApiClient.default) ⇒ RepositoriesContainerApi
constructor
A new instance of RepositoriesContainerApi.
-
#list(opts = {}) ⇒ InlineResponse2005
List container repositorys ViewSet for container repo.
-
#list_with_http_info(opts = {}) ⇒ Array<(InlineResponse2005, Integer, Hash)>
List container repositorys ViewSet for container repo.
-
#partial_update(container_repository_href, data, opts = {}) ⇒ ContainerContainerRepository
Partially update a container repository ViewSet for container repo.
-
#partial_update_with_http_info(container_repository_href, data, opts = {}) ⇒ Array<(ContainerContainerRepository, Integer, Hash)>
Partially update a container repository ViewSet for container repo.
-
#read(container_repository_href, opts = {}) ⇒ ContainerContainerRepository
Inspect a container repository ViewSet for container repo.
-
#read_with_http_info(container_repository_href, opts = {}) ⇒ Array<(ContainerContainerRepository, Integer, Hash)>
Inspect a container repository ViewSet for container repo.
-
#remove(container_repository_href, data, opts = {}) ⇒ AsyncOperationResponse
Remove content Trigger an async task to recursively remove container content.
-
#remove_with_http_info(container_repository_href, data, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Remove content Trigger an async task to recursively remove container content.
-
#sync(container_repository_href, data, opts = {}) ⇒ AsyncOperationResponse
Sync from a remote Trigger an asynchronous task to sync content.
-
#sync_with_http_info(container_repository_href, data, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Sync from a remote Trigger an asynchronous task to sync content.
-
#tag(container_repository_href, data, opts = {}) ⇒ AsyncOperationResponse
Create a Tag Trigger an asynchronous task to tag an image in the repository.
-
#tag_with_http_info(container_repository_href, data, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Create a Tag Trigger an asynchronous task to tag an image in the repository.
-
#untag(container_repository_href, data, opts = {}) ⇒ AsyncOperationResponse
Delete a tag Trigger an asynchronous task to untag an image in the repository.
-
#untag_with_http_info(container_repository_href, data, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Delete a tag Trigger an asynchronous task to untag an image in the repository.
-
#update(container_repository_href, data, opts = {}) ⇒ AsyncOperationResponse
Update a container repository Trigger an asynchronous task to update a repository.
-
#update_with_http_info(container_repository_href, data, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Update a container repository Trigger an asynchronous task to update a repository.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ RepositoriesContainerApi
Returns a new instance of RepositoriesContainerApi.
19 20 21 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#add(container_repository_href, data, opts = {}) ⇒ AsyncOperationResponse
Add content Trigger an asynchronous task to recursively add container content.
28 29 30 31 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 28 def add(container_repository_href, data, opts = {}) data, _status_code, _headers = add_with_http_info(container_repository_href, data, opts) data end |
#add_with_http_info(container_repository_href, data, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Add content Trigger an asynchronous task to recursively add container content.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 39 def add_with_http_info(container_repository_href, data, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerApi.add ...' end # verify the required parameter 'container_repository_href' is set if @api_client.config.client_side_validation && container_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_repository_href' when calling RepositoriesContainerApi.add" end # verify the required parameter 'data' is set if @api_client.config.client_side_validation && data.nil? fail ArgumentError, "Missing the required parameter 'data' when calling RepositoriesContainerApi.add" end # resource path local_var_path = '{container_repository_href}add/'.sub('{' + 'container_repository_href' + '}', CGI.escape(container_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(data) # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['Basic'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerApi#add\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#build_image(container_repository_href, opts = {}) ⇒ AsyncOperationResponse
Build an Image Trigger an asynchronous task to build an OCI image from a Containerfile. A new repository version is created with the new image and tag. This API is tech preview in Pulp Container 1.1. Backwards compatibility when upgrading is not guaranteed.
101 102 103 104 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 101 def build_image(container_repository_href, opts = {}) data, _status_code, _headers = build_image_with_http_info(container_repository_href, opts) data end |
#build_image_with_http_info(container_repository_href, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Build an Image Trigger an asynchronous task to build an OCI image from a Containerfile. A new repository version is created with the new image and tag. This API is tech preview in Pulp Container 1.1. Backwards compatibility when upgrading is not guaranteed.
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 115 def build_image_with_http_info(container_repository_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerApi.build_image ...' end # verify the required parameter 'container_repository_href' is set if @api_client.config.client_side_validation && container_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_repository_href' when calling RepositoriesContainerApi.build_image" end if @api_client.config.client_side_validation && !opts[:'tag'].nil? && opts[:'tag'].to_s.length < 1 fail ArgumentError, 'invalid value for "opts[:"tag"]" when calling RepositoriesContainerApi.build_image, the character length must be great than or equal to 1.' end # resource path local_var_path = '{container_repository_href}build_image/'.sub('{' + 'container_repository_href' + '}', CGI.escape(container_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data', 'application/x-www-form-urlencoded']) # form parameters form_params = opts[:form_params] || {} form_params['containerfile_artifact'] = opts[:'containerfile_artifact'] if !opts[:'containerfile_artifact'].nil? form_params['containerfile'] = opts[:'containerfile'] if !opts[:'containerfile'].nil? form_params['tag'] = opts[:'tag'] if !opts[:'tag'].nil? form_params['artifacts'] = opts[:'artifacts'] if !opts[:'artifacts'].nil? # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['Basic'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerApi#build_image\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#copy_manifests(container_repository_href, data, opts = {}) ⇒ AsyncOperationResponse
Copy manifests Trigger an asynchronous task to copy manifests
178 179 180 181 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 178 def copy_manifests(container_repository_href, data, opts = {}) data, _status_code, _headers = copy_manifests_with_http_info(container_repository_href, data, opts) data end |
#copy_manifests_with_http_info(container_repository_href, data, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Copy manifests Trigger an asynchronous task to copy manifests
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 189 def copy_manifests_with_http_info(container_repository_href, data, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerApi.copy_manifests ...' end # verify the required parameter 'container_repository_href' is set if @api_client.config.client_side_validation && container_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_repository_href' when calling RepositoriesContainerApi.copy_manifests" end # verify the required parameter 'data' is set if @api_client.config.client_side_validation && data.nil? fail ArgumentError, "Missing the required parameter 'data' when calling RepositoriesContainerApi.copy_manifests" end # resource path local_var_path = '{container_repository_href}copy_manifests/'.sub('{' + 'container_repository_href' + '}', CGI.escape(container_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(data) # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['Basic'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerApi#copy_manifests\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#copy_tags(container_repository_href, data, opts = {}) ⇒ AsyncOperationResponse
Copy tags Trigger an asynchronous task to copy tags
248 249 250 251 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 248 def (container_repository_href, data, opts = {}) data, _status_code, _headers = (container_repository_href, data, opts) data end |
#copy_tags_with_http_info(container_repository_href, data, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Copy tags Trigger an asynchronous task to copy tags
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 259 def (container_repository_href, data, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerApi.copy_tags ...' end # verify the required parameter 'container_repository_href' is set if @api_client.config.client_side_validation && container_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_repository_href' when calling RepositoriesContainerApi.copy_tags" end # verify the required parameter 'data' is set if @api_client.config.client_side_validation && data.nil? fail ArgumentError, "Missing the required parameter 'data' when calling RepositoriesContainerApi.copy_tags" end # resource path local_var_path = '{container_repository_href}copy_tags/'.sub('{' + 'container_repository_href' + '}', CGI.escape(container_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(data) # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['Basic'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerApi#copy_tags\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create(data, opts = {}) ⇒ ContainerContainerRepository
Create a container repository ViewSet for container repo.
317 318 319 320 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 317 def create(data, opts = {}) data, _status_code, _headers = create_with_http_info(data, opts) data end |
#create_with_http_info(data, opts = {}) ⇒ Array<(ContainerContainerRepository, Integer, Hash)>
Create a container repository ViewSet for container repo.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 327 def create_with_http_info(data, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerApi.create ...' end # verify the required parameter 'data' is set if @api_client.config.client_side_validation && data.nil? fail ArgumentError, "Missing the required parameter 'data' when calling RepositoriesContainerApi.create" end # resource path local_var_path = '/pulp/api/v3/repositories/container/container/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(data) # return_type return_type = opts[:return_type] || 'ContainerContainerRepository' # auth_names auth_names = opts[:auth_names] || ['Basic'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerApi#create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete(container_repository_href, opts = {}) ⇒ AsyncOperationResponse
Delete a container repository Trigger an asynchronous task to delete a repository.
381 382 383 384 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 381 def delete(container_repository_href, opts = {}) data, _status_code, _headers = delete_with_http_info(container_repository_href, opts) data end |
#delete_with_http_info(container_repository_href, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Delete a container repository Trigger an asynchronous task to delete a repository.
391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 391 def delete_with_http_info(container_repository_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerApi.delete ...' end # verify the required parameter 'container_repository_href' is set if @api_client.config.client_side_validation && container_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_repository_href' when calling RepositoriesContainerApi.delete" end # resource path local_var_path = '{container_repository_href}'.sub('{' + 'container_repository_href' + '}', CGI.escape(container_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['Basic'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerApi#delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list(opts = {}) ⇒ InlineResponse2005
List container repositorys ViewSet for container repo.
448 449 450 451 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 448 def list(opts = {}) data, _status_code, _headers = list_with_http_info(opts) data end |
#list_with_http_info(opts = {}) ⇒ Array<(InlineResponse2005, Integer, Hash)>
List container repositorys ViewSet for container repo.
463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 463 def list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerApi.list ...' end # resource path local_var_path = '/pulp/api/v3/repositories/container/container/' # query parameters query_params = opts[:query_params] || {} query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil? query_params[:'name__in'] = opts[:'name__in'] if !opts[:'name__in'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'fields'] = opts[:'fields'] if !opts[:'fields'].nil? query_params[:'exclude_fields'] = opts[:'exclude_fields'] if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'InlineResponse2005' # auth_names auth_names = opts[:auth_names] || ['Basic'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerApi#list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#partial_update(container_repository_href, data, opts = {}) ⇒ ContainerContainerRepository
Partially update a container repository ViewSet for container repo.
518 519 520 521 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 518 def partial_update(container_repository_href, data, opts = {}) data, _status_code, _headers = partial_update_with_http_info(container_repository_href, data, opts) data end |
#partial_update_with_http_info(container_repository_href, data, opts = {}) ⇒ Array<(ContainerContainerRepository, Integer, Hash)>
Partially update a container repository ViewSet for container repo.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 529 def partial_update_with_http_info(container_repository_href, data, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerApi.partial_update ...' end # verify the required parameter 'container_repository_href' is set if @api_client.config.client_side_validation && container_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_repository_href' when calling RepositoriesContainerApi.partial_update" end # verify the required parameter 'data' is set if @api_client.config.client_side_validation && data.nil? fail ArgumentError, "Missing the required parameter 'data' when calling RepositoriesContainerApi.partial_update" end # resource path local_var_path = '{container_repository_href}'.sub('{' + 'container_repository_href' + '}', CGI.escape(container_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(data) # return_type return_type = opts[:return_type] || 'ContainerContainerRepository' # auth_names auth_names = opts[:auth_names] || ['Basic'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerApi#partial_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#read(container_repository_href, opts = {}) ⇒ ContainerContainerRepository
Inspect a container repository ViewSet for container repo.
589 590 591 592 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 589 def read(container_repository_href, opts = {}) data, _status_code, _headers = read_with_http_info(container_repository_href, opts) data end |
#read_with_http_info(container_repository_href, opts = {}) ⇒ Array<(ContainerContainerRepository, Integer, Hash)>
Inspect a container repository ViewSet for container repo.
601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 601 def read_with_http_info(container_repository_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerApi.read ...' end # verify the required parameter 'container_repository_href' is set if @api_client.config.client_side_validation && container_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_repository_href' when calling RepositoriesContainerApi.read" end # resource path local_var_path = '{container_repository_href}'.sub('{' + 'container_repository_href' + '}', CGI.escape(container_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = opts[:'fields'] if !opts[:'fields'].nil? query_params[:'exclude_fields'] = opts[:'exclude_fields'] if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'ContainerContainerRepository' # auth_names auth_names = opts[:auth_names] || ['Basic'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerApi#read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#remove(container_repository_href, data, opts = {}) ⇒ AsyncOperationResponse
Remove content Trigger an async task to recursively remove container content.
656 657 658 659 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 656 def remove(container_repository_href, data, opts = {}) data, _status_code, _headers = remove_with_http_info(container_repository_href, data, opts) data end |
#remove_with_http_info(container_repository_href, data, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Remove content Trigger an async task to recursively remove container content.
667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 667 def remove_with_http_info(container_repository_href, data, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerApi.remove ...' end # verify the required parameter 'container_repository_href' is set if @api_client.config.client_side_validation && container_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_repository_href' when calling RepositoriesContainerApi.remove" end # verify the required parameter 'data' is set if @api_client.config.client_side_validation && data.nil? fail ArgumentError, "Missing the required parameter 'data' when calling RepositoriesContainerApi.remove" end # resource path local_var_path = '{container_repository_href}remove/'.sub('{' + 'container_repository_href' + '}', CGI.escape(container_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(data) # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['Basic'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerApi#remove\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#sync(container_repository_href, data, opts = {}) ⇒ AsyncOperationResponse
Sync from a remote Trigger an asynchronous task to sync content.
726 727 728 729 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 726 def sync(container_repository_href, data, opts = {}) data, _status_code, _headers = sync_with_http_info(container_repository_href, data, opts) data end |
#sync_with_http_info(container_repository_href, data, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Sync from a remote Trigger an asynchronous task to sync content.
737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 737 def sync_with_http_info(container_repository_href, data, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerApi.sync ...' end # verify the required parameter 'container_repository_href' is set if @api_client.config.client_side_validation && container_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_repository_href' when calling RepositoriesContainerApi.sync" end # verify the required parameter 'data' is set if @api_client.config.client_side_validation && data.nil? fail ArgumentError, "Missing the required parameter 'data' when calling RepositoriesContainerApi.sync" end # resource path local_var_path = '{container_repository_href}sync/'.sub('{' + 'container_repository_href' + '}', CGI.escape(container_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(data) # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['Basic'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerApi#sync\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#tag(container_repository_href, data, opts = {}) ⇒ AsyncOperationResponse
Create a Tag Trigger an asynchronous task to tag an image in the repository
796 797 798 799 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 796 def tag(container_repository_href, data, opts = {}) data, _status_code, _headers = tag_with_http_info(container_repository_href, data, opts) data end |
#tag_with_http_info(container_repository_href, data, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Create a Tag Trigger an asynchronous task to tag an image in the repository
807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 807 def tag_with_http_info(container_repository_href, data, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerApi.tag ...' end # verify the required parameter 'container_repository_href' is set if @api_client.config.client_side_validation && container_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_repository_href' when calling RepositoriesContainerApi.tag" end # verify the required parameter 'data' is set if @api_client.config.client_side_validation && data.nil? fail ArgumentError, "Missing the required parameter 'data' when calling RepositoriesContainerApi.tag" end # resource path local_var_path = '{container_repository_href}tag/'.sub('{' + 'container_repository_href' + '}', CGI.escape(container_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(data) # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['Basic'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerApi#tag\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#untag(container_repository_href, data, opts = {}) ⇒ AsyncOperationResponse
Delete a tag Trigger an asynchronous task to untag an image in the repository
866 867 868 869 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 866 def untag(container_repository_href, data, opts = {}) data, _status_code, _headers = untag_with_http_info(container_repository_href, data, opts) data end |
#untag_with_http_info(container_repository_href, data, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Delete a tag Trigger an asynchronous task to untag an image in the repository
877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 877 def untag_with_http_info(container_repository_href, data, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerApi.untag ...' end # verify the required parameter 'container_repository_href' is set if @api_client.config.client_side_validation && container_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_repository_href' when calling RepositoriesContainerApi.untag" end # verify the required parameter 'data' is set if @api_client.config.client_side_validation && data.nil? fail ArgumentError, "Missing the required parameter 'data' when calling RepositoriesContainerApi.untag" end # resource path local_var_path = '{container_repository_href}untag/'.sub('{' + 'container_repository_href' + '}', CGI.escape(container_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(data) # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['Basic'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerApi#untag\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update(container_repository_href, data, opts = {}) ⇒ AsyncOperationResponse
Update a container repository Trigger an asynchronous task to update a repository.
936 937 938 939 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 936 def update(container_repository_href, data, opts = {}) data, _status_code, _headers = update_with_http_info(container_repository_href, data, opts) data end |
#update_with_http_info(container_repository_href, data, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Update a container repository Trigger an asynchronous task to update a repository.
947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 |
# File 'lib/pulp_container_client/api/repositories_container_api.rb', line 947 def update_with_http_info(container_repository_href, data, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerApi.update ...' end # verify the required parameter 'container_repository_href' is set if @api_client.config.client_side_validation && container_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_repository_href' when calling RepositoriesContainerApi.update" end # verify the required parameter 'data' is set if @api_client.config.client_side_validation && data.nil? fail ArgumentError, "Missing the required parameter 'data' when calling RepositoriesContainerApi.update" end # resource path local_var_path = '{container_repository_href}'.sub('{' + 'container_repository_href' + '}', CGI.escape(container_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(data) # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['Basic'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerApi#update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |