Class: PulpContainerClient::RepositoriesContainerPushApi
- Inherits:
-
Object
- Object
- PulpContainerClient::RepositoriesContainerPushApi
- Defined in:
- lib/pulp_container_client/api/repositories_container_push_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#add_role(container_container_push_repository_href, nested_role, opts = {}) ⇒ NestedRoleResponse
Add a role Add a role for this object to users/groups.
-
#add_role_with_http_info(container_container_push_repository_href, nested_role, opts = {}) ⇒ Array<(NestedRoleResponse, Integer, Hash)>
Add a role Add a role for this object to users/groups.
-
#initialize(api_client = ApiClient.default) ⇒ RepositoriesContainerPushApi
constructor
A new instance of RepositoriesContainerPushApi.
-
#list(opts = {}) ⇒ PaginatedcontainerContainerPushRepositoryResponseList
List container push repositorys ViewSet for a container push repository.
-
#list_roles(container_container_push_repository_href, opts = {}) ⇒ ObjectRolesResponse
List roles List roles assigned to this object.
-
#list_roles_with_http_info(container_container_push_repository_href, opts = {}) ⇒ Array<(ObjectRolesResponse, Integer, Hash)>
List roles List roles assigned to this object.
-
#list_with_http_info(opts = {}) ⇒ Array<(PaginatedcontainerContainerPushRepositoryResponseList, Integer, Hash)>
List container push repositorys ViewSet for a container push repository.
-
#my_permissions(container_container_push_repository_href, opts = {}) ⇒ MyPermissionsResponse
List user permissions List permissions available to the current user on this object.
-
#my_permissions_with_http_info(container_container_push_repository_href, opts = {}) ⇒ Array<(MyPermissionsResponse, Integer, Hash)>
List user permissions List permissions available to the current user on this object.
-
#partial_update(container_container_push_repository_href, patchedcontainer_container_push_repository, opts = {}) ⇒ ContainerContainerPushRepositoryResponse
Update a container push repository Update the entity partially and trigger an asynchronous task if necessary.
-
#partial_update_with_http_info(container_container_push_repository_href, patchedcontainer_container_push_repository, opts = {}) ⇒ Array<(ContainerContainerPushRepositoryResponse, Integer, Hash)>
Update a container push repository Update the entity partially and trigger an asynchronous task if necessary.
-
#read(container_container_push_repository_href, opts = {}) ⇒ ContainerContainerPushRepositoryResponse
Inspect a container push repository ViewSet for a container push repository.
-
#read_with_http_info(container_container_push_repository_href, opts = {}) ⇒ Array<(ContainerContainerPushRepositoryResponse, Integer, Hash)>
Inspect a container push repository ViewSet for a container push repository.
-
#remove_image(container_container_push_repository_href, remove_image, opts = {}) ⇒ AsyncOperationResponse
Delete an image from a repository Trigger an asynchronous task to remove a manifest and all its associated data by a digest.
-
#remove_image_with_http_info(container_container_push_repository_href, remove_image, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Delete an image from a repository Trigger an asynchronous task to remove a manifest and all its associated data by a digest.
-
#remove_role(container_container_push_repository_href, nested_role, opts = {}) ⇒ NestedRoleResponse
Remove a role Remove a role for this object from users/groups.
-
#remove_role_with_http_info(container_container_push_repository_href, nested_role, opts = {}) ⇒ Array<(NestedRoleResponse, Integer, Hash)>
Remove a role Remove a role for this object from users/groups.
-
#remove_signatures(container_container_push_repository_href, remove_signatures, opts = {}) ⇒ RemoveSignaturesResponse
Create a task which deletes signatures by the passed key_id.
-
#remove_signatures_with_http_info(container_container_push_repository_href, remove_signatures, opts = {}) ⇒ Array<(RemoveSignaturesResponse, Integer, Hash)>
Create a task which deletes signatures by the passed key_id.
-
#sign(container_container_push_repository_href, repository_sign, opts = {}) ⇒ AsyncOperationResponse
Sign images in the repo Trigger an asynchronous task to sign content.
-
#sign_with_http_info(container_container_push_repository_href, repository_sign, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Sign images in the repo Trigger an asynchronous task to sign content.
-
#tag(container_container_push_repository_href, tag_image, opts = {}) ⇒ AsyncOperationResponse
Create a Tag Trigger an asynchronous task to tag an image in the repository.
-
#tag_with_http_info(container_container_push_repository_href, tag_image, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Create a Tag Trigger an asynchronous task to tag an image in the repository.
-
#untag(container_container_push_repository_href, un_tag_image, opts = {}) ⇒ AsyncOperationResponse
Delete a tag Trigger an asynchronous task to untag an image in the repository.
-
#untag_with_http_info(container_container_push_repository_href, un_tag_image, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Delete a tag Trigger an asynchronous task to untag an image in the repository.
-
#update(container_container_push_repository_href, container_container_push_repository, opts = {}) ⇒ ContainerContainerPushRepositoryResponse
Update a container push repository Update the entity and trigger an asynchronous task if necessary.
-
#update_with_http_info(container_container_push_repository_href, container_container_push_repository, opts = {}) ⇒ Array<(ContainerContainerPushRepositoryResponse, Integer, Hash)>
Update a container push repository Update the entity and trigger an asynchronous task if necessary.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ RepositoriesContainerPushApi
Returns a new instance of RepositoriesContainerPushApi.
19 20 21 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#add_role(container_container_push_repository_href, nested_role, opts = {}) ⇒ NestedRoleResponse
Add a role Add a role for this object to users/groups.
29 30 31 32 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 29 def add_role(container_container_push_repository_href, nested_role, opts = {}) data, _status_code, _headers = add_role_with_http_info(container_container_push_repository_href, nested_role, opts) data end |
#add_role_with_http_info(container_container_push_repository_href, nested_role, opts = {}) ⇒ Array<(NestedRoleResponse, Integer, Hash)>
Add a role Add a role for this object to users/groups.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 41 def add_role_with_http_info(container_container_push_repository_href, nested_role, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerPushApi.add_role ...' end # verify the required parameter 'container_container_push_repository_href' is set if @api_client.config.client_side_validation && container_container_push_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_container_push_repository_href' when calling RepositoriesContainerPushApi.add_role" end # verify the required parameter 'nested_role' is set if @api_client.config.client_side_validation && nested_role.nil? fail ArgumentError, "Missing the required parameter 'nested_role' when calling RepositoriesContainerPushApi.add_role" end # resource path local_var_path = '{container_container_push_repository_href}add_role/'.sub('{' + 'container_container_push_repository_href' + '}', CGI.escape(container_container_push_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(nested_role) # return_type return_type = opts[:debug_return_type] || 'NestedRoleResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"RepositoriesContainerPushApi.add_role", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerPushApi#add_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list(opts = {}) ⇒ PaginatedcontainerContainerPushRepositoryResponseList
List container push repositorys ViewSet for a container push repository. POST and DELETE are disallowed because a push repository is tightly coupled with a ContainerDistribution which handles it automatically. Created - during push operation, removed - with ContainerDistribution removal.
142 143 144 145 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 142 def list(opts = {}) data, _status_code, _headers = list_with_http_info(opts) data end |
#list_roles(container_container_push_repository_href, opts = {}) ⇒ ObjectRolesResponse
List roles List roles assigned to this object.
285 286 287 288 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 285 def list_roles(container_container_push_repository_href, opts = {}) data, _status_code, _headers = list_roles_with_http_info(container_container_push_repository_href, opts) data end |
#list_roles_with_http_info(container_container_push_repository_href, opts = {}) ⇒ Array<(ObjectRolesResponse, Integer, Hash)>
List roles List roles assigned to this object.
298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 298 def list_roles_with_http_info(container_container_push_repository_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerPushApi.list_roles ...' end # verify the required parameter 'container_container_push_repository_href' is set if @api_client.config.client_side_validation && container_container_push_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_container_push_repository_href' when calling RepositoriesContainerPushApi.list_roles" end # resource path local_var_path = '{container_container_push_repository_href}list_roles/'.sub('{' + 'container_container_push_repository_href' + '}', CGI.escape(container_container_push_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ObjectRolesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"RepositoriesContainerPushApi.list_roles", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerPushApi#list_roles\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_with_http_info(opts = {}) ⇒ Array<(PaginatedcontainerContainerPushRepositoryResponseList, Integer, Hash)>
List container push repositorys ViewSet for a container push repository. POST and DELETE are disallowed because a push repository is tightly coupled with a ContainerDistribution which handles it automatically. Created - during push operation, removed - with ContainerDistribution removal.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 190 def list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerPushApi.list ...' end allowable_values = ["-description", "-name", "-next_version", "-pk", "-pulp_created", "-pulp_id", "-pulp_labels", "-pulp_last_updated", "-pulp_type", "-retain_checkpoints", "-retain_repo_versions", "-user_hidden", "description", "name", "next_version", "pk", "pulp_created", "pulp_id", "pulp_labels", "pulp_last_updated", "pulp_type", "retain_checkpoints", "retain_repo_versions", "user_hidden"] if @api_client.config.client_side_validation && opts[:'ordering'] && !opts[:'ordering'].all? { |item| allowable_values.include?(item) } fail ArgumentError, "invalid value for \"ordering\", must include one of #{allowable_values}" end # resource path local_var_path = '/pulp/api/v3/repositories/container/container-push/' # query parameters query_params = opts[:query_params] || {} query_params[:'latest_with_content'] = opts[:'latest_with_content'] if !opts[:'latest_with_content'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil? query_params[:'name__contains'] = opts[:'name__contains'] if !opts[:'name__contains'].nil? query_params[:'name__icontains'] = opts[:'name__icontains'] if !opts[:'name__icontains'].nil? query_params[:'name__iexact'] = opts[:'name__iexact'] if !opts[:'name__iexact'].nil? query_params[:'name__in'] = @api_client.build_collection_param(opts[:'name__in'], :csv) if !opts[:'name__in'].nil? query_params[:'name__iregex'] = opts[:'name__iregex'] if !opts[:'name__iregex'].nil? query_params[:'name__istartswith'] = opts[:'name__istartswith'] if !opts[:'name__istartswith'].nil? query_params[:'name__regex'] = opts[:'name__regex'] if !opts[:'name__regex'].nil? query_params[:'name__startswith'] = opts[:'name__startswith'] if !opts[:'name__startswith'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'ordering'] = @api_client.build_collection_param(opts[:'ordering'], :csv) if !opts[:'ordering'].nil? query_params[:'prn__in'] = @api_client.build_collection_param(opts[:'prn__in'], :csv) if !opts[:'prn__in'].nil? query_params[:'pulp_href__in'] = @api_client.build_collection_param(opts[:'pulp_href__in'], :csv) if !opts[:'pulp_href__in'].nil? query_params[:'pulp_id__in'] = @api_client.build_collection_param(opts[:'pulp_id__in'], :csv) if !opts[:'pulp_id__in'].nil? query_params[:'pulp_label_select'] = opts[:'pulp_label_select'] if !opts[:'pulp_label_select'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? query_params[:'remote'] = opts[:'remote'] if !opts[:'remote'].nil? query_params[:'retain_checkpoints'] = opts[:'retain_checkpoints'] if !opts[:'retain_checkpoints'].nil? query_params[:'retain_checkpoints__gt'] = opts[:'retain_checkpoints__gt'] if !opts[:'retain_checkpoints__gt'].nil? query_params[:'retain_checkpoints__gte'] = opts[:'retain_checkpoints__gte'] if !opts[:'retain_checkpoints__gte'].nil? query_params[:'retain_checkpoints__isnull'] = opts[:'retain_checkpoints__isnull'] if !opts[:'retain_checkpoints__isnull'].nil? query_params[:'retain_checkpoints__lt'] = opts[:'retain_checkpoints__lt'] if !opts[:'retain_checkpoints__lt'].nil? query_params[:'retain_checkpoints__lte'] = opts[:'retain_checkpoints__lte'] if !opts[:'retain_checkpoints__lte'].nil? query_params[:'retain_checkpoints__ne'] = opts[:'retain_checkpoints__ne'] if !opts[:'retain_checkpoints__ne'].nil? query_params[:'retain_checkpoints__range'] = @api_client.build_collection_param(opts[:'retain_checkpoints__range'], :csv) if !opts[:'retain_checkpoints__range'].nil? query_params[:'retain_repo_versions'] = opts[:'retain_repo_versions'] if !opts[:'retain_repo_versions'].nil? query_params[:'retain_repo_versions__gt'] = opts[:'retain_repo_versions__gt'] if !opts[:'retain_repo_versions__gt'].nil? query_params[:'retain_repo_versions__gte'] = opts[:'retain_repo_versions__gte'] if !opts[:'retain_repo_versions__gte'].nil? query_params[:'retain_repo_versions__isnull'] = opts[:'retain_repo_versions__isnull'] if !opts[:'retain_repo_versions__isnull'].nil? query_params[:'retain_repo_versions__lt'] = opts[:'retain_repo_versions__lt'] if !opts[:'retain_repo_versions__lt'].nil? query_params[:'retain_repo_versions__lte'] = opts[:'retain_repo_versions__lte'] if !opts[:'retain_repo_versions__lte'].nil? query_params[:'retain_repo_versions__ne'] = opts[:'retain_repo_versions__ne'] if !opts[:'retain_repo_versions__ne'].nil? query_params[:'retain_repo_versions__range'] = @api_client.build_collection_param(opts[:'retain_repo_versions__range'], :csv) if !opts[:'retain_repo_versions__range'].nil? query_params[:'with_content'] = opts[:'with_content'] if !opts[:'with_content'].nil? query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginatedcontainerContainerPushRepositoryResponseList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"RepositoriesContainerPushApi.list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerPushApi#list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#my_permissions(container_container_push_repository_href, opts = {}) ⇒ MyPermissionsResponse
List user permissions List permissions available to the current user on this object.
357 358 359 360 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 357 def (container_container_push_repository_href, opts = {}) data, _status_code, _headers = (container_container_push_repository_href, opts) data end |
#my_permissions_with_http_info(container_container_push_repository_href, opts = {}) ⇒ Array<(MyPermissionsResponse, Integer, Hash)>
List user permissions List permissions available to the current user on this object.
370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 370 def (container_container_push_repository_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerPushApi.my_permissions ...' end # verify the required parameter 'container_container_push_repository_href' is set if @api_client.config.client_side_validation && container_container_push_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_container_push_repository_href' when calling RepositoriesContainerPushApi.my_permissions" end # resource path local_var_path = '{container_container_push_repository_href}my_permissions/'.sub('{' + 'container_container_push_repository_href' + '}', CGI.escape(container_container_push_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MyPermissionsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"RepositoriesContainerPushApi.my_permissions", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerPushApi#my_permissions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#partial_update(container_container_push_repository_href, patchedcontainer_container_push_repository, opts = {}) ⇒ ContainerContainerPushRepositoryResponse
Update a container push repository Update the entity partially and trigger an asynchronous task if necessary
428 429 430 431 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 428 def partial_update(container_container_push_repository_href, patchedcontainer_container_push_repository, opts = {}) data, _status_code, _headers = partial_update_with_http_info(container_container_push_repository_href, patchedcontainer_container_push_repository, opts) data end |
#partial_update_with_http_info(container_container_push_repository_href, patchedcontainer_container_push_repository, opts = {}) ⇒ Array<(ContainerContainerPushRepositoryResponse, Integer, Hash)>
Update a container push repository Update the entity partially and trigger an asynchronous task if necessary
440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 440 def partial_update_with_http_info(container_container_push_repository_href, patchedcontainer_container_push_repository, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerPushApi.partial_update ...' end # verify the required parameter 'container_container_push_repository_href' is set if @api_client.config.client_side_validation && container_container_push_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_container_push_repository_href' when calling RepositoriesContainerPushApi.partial_update" end # verify the required parameter 'patchedcontainer_container_push_repository' is set if @api_client.config.client_side_validation && patchedcontainer_container_push_repository.nil? fail ArgumentError, "Missing the required parameter 'patchedcontainer_container_push_repository' when calling RepositoriesContainerPushApi.partial_update" end # resource path local_var_path = '{container_container_push_repository_href}'.sub('{' + 'container_container_push_repository_href' + '}', CGI.escape(container_container_push_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(patchedcontainer_container_push_repository) # return_type return_type = opts[:debug_return_type] || 'ContainerContainerPushRepositoryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"RepositoriesContainerPushApi.partial_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerPushApi#partial_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#read(container_container_push_repository_href, opts = {}) ⇒ ContainerContainerPushRepositoryResponse
Inspect a container push repository ViewSet for a container push repository. POST and DELETE are disallowed because a push repository is tightly coupled with a ContainerDistribution which handles it automatically. Created - during push operation, removed - with ContainerDistribution removal.
506 507 508 509 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 506 def read(container_container_push_repository_href, opts = {}) data, _status_code, _headers = read_with_http_info(container_container_push_repository_href, opts) data end |
#read_with_http_info(container_container_push_repository_href, opts = {}) ⇒ Array<(ContainerContainerPushRepositoryResponse, Integer, Hash)>
Inspect a container push repository ViewSet for a container push repository. POST and DELETE are disallowed because a push repository is tightly coupled with a ContainerDistribution which handles it automatically. Created - during push operation, removed - with ContainerDistribution removal.
519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 519 def read_with_http_info(container_container_push_repository_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerPushApi.read ...' end # verify the required parameter 'container_container_push_repository_href' is set if @api_client.config.client_side_validation && container_container_push_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_container_push_repository_href' when calling RepositoriesContainerPushApi.read" end # resource path local_var_path = '{container_container_push_repository_href}'.sub('{' + 'container_container_push_repository_href' + '}', CGI.escape(container_container_push_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ContainerContainerPushRepositoryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"RepositoriesContainerPushApi.read", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerPushApi#read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#remove_image(container_container_push_repository_href, remove_image, opts = {}) ⇒ AsyncOperationResponse
Delete an image from a repository Trigger an asynchronous task to remove a manifest and all its associated data by a digest
577 578 579 580 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 577 def remove_image(container_container_push_repository_href, remove_image, opts = {}) data, _status_code, _headers = remove_image_with_http_info(container_container_push_repository_href, remove_image, opts) data end |
#remove_image_with_http_info(container_container_push_repository_href, remove_image, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Delete an image from a repository Trigger an asynchronous task to remove a manifest and all its associated data by a digest
589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 589 def remove_image_with_http_info(container_container_push_repository_href, remove_image, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerPushApi.remove_image ...' end # verify the required parameter 'container_container_push_repository_href' is set if @api_client.config.client_side_validation && container_container_push_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_container_push_repository_href' when calling RepositoriesContainerPushApi.remove_image" end # verify the required parameter 'remove_image' is set if @api_client.config.client_side_validation && remove_image.nil? fail ArgumentError, "Missing the required parameter 'remove_image' when calling RepositoriesContainerPushApi.remove_image" end # resource path local_var_path = '{container_container_push_repository_href}remove_image/'.sub('{' + 'container_container_push_repository_href' + '}', CGI.escape(container_container_push_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(remove_image) # return_type return_type = opts[:debug_return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"RepositoriesContainerPushApi.remove_image", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerPushApi#remove_image\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#remove_role(container_container_push_repository_href, nested_role, opts = {}) ⇒ NestedRoleResponse
Remove a role Remove a role for this object from users/groups.
654 655 656 657 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 654 def remove_role(container_container_push_repository_href, nested_role, opts = {}) data, _status_code, _headers = remove_role_with_http_info(container_container_push_repository_href, nested_role, opts) data end |
#remove_role_with_http_info(container_container_push_repository_href, nested_role, opts = {}) ⇒ Array<(NestedRoleResponse, Integer, Hash)>
Remove a role Remove a role for this object from users/groups.
666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 666 def remove_role_with_http_info(container_container_push_repository_href, nested_role, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerPushApi.remove_role ...' end # verify the required parameter 'container_container_push_repository_href' is set if @api_client.config.client_side_validation && container_container_push_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_container_push_repository_href' when calling RepositoriesContainerPushApi.remove_role" end # verify the required parameter 'nested_role' is set if @api_client.config.client_side_validation && nested_role.nil? fail ArgumentError, "Missing the required parameter 'nested_role' when calling RepositoriesContainerPushApi.remove_role" end # resource path local_var_path = '{container_container_push_repository_href}remove_role/'.sub('{' + 'container_container_push_repository_href' + '}', CGI.escape(container_container_push_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(nested_role) # return_type return_type = opts[:debug_return_type] || 'NestedRoleResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"RepositoriesContainerPushApi.remove_role", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerPushApi#remove_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#remove_signatures(container_container_push_repository_href, remove_signatures, opts = {}) ⇒ RemoveSignaturesResponse
Create a task which deletes signatures by the passed key_id.
730 731 732 733 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 730 def remove_signatures(container_container_push_repository_href, remove_signatures, opts = {}) data, _status_code, _headers = remove_signatures_with_http_info(container_container_push_repository_href, remove_signatures, opts) data end |
#remove_signatures_with_http_info(container_container_push_repository_href, remove_signatures, opts = {}) ⇒ Array<(RemoveSignaturesResponse, Integer, Hash)>
Create a task which deletes signatures by the passed key_id.
741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 741 def remove_signatures_with_http_info(container_container_push_repository_href, remove_signatures, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerPushApi.remove_signatures ...' end # verify the required parameter 'container_container_push_repository_href' is set if @api_client.config.client_side_validation && container_container_push_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_container_push_repository_href' when calling RepositoriesContainerPushApi.remove_signatures" end # verify the required parameter 'remove_signatures' is set if @api_client.config.client_side_validation && remove_signatures.nil? fail ArgumentError, "Missing the required parameter 'remove_signatures' when calling RepositoriesContainerPushApi.remove_signatures" end # resource path local_var_path = '{container_container_push_repository_href}remove_signatures/'.sub('{' + 'container_container_push_repository_href' + '}', CGI.escape(container_container_push_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(remove_signatures) # return_type return_type = opts[:debug_return_type] || 'RemoveSignaturesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"RepositoriesContainerPushApi.remove_signatures", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerPushApi#remove_signatures\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#sign(container_container_push_repository_href, repository_sign, opts = {}) ⇒ AsyncOperationResponse
Sign images in the repo Trigger an asynchronous task to sign content.
806 807 808 809 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 806 def sign(container_container_push_repository_href, repository_sign, opts = {}) data, _status_code, _headers = sign_with_http_info(container_container_push_repository_href, repository_sign, opts) data end |
#sign_with_http_info(container_container_push_repository_href, repository_sign, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Sign images in the repo Trigger an asynchronous task to sign content.
818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 818 def sign_with_http_info(container_container_push_repository_href, repository_sign, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerPushApi.sign ...' end # verify the required parameter 'container_container_push_repository_href' is set if @api_client.config.client_side_validation && container_container_push_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_container_push_repository_href' when calling RepositoriesContainerPushApi.sign" end # verify the required parameter 'repository_sign' is set if @api_client.config.client_side_validation && repository_sign.nil? fail ArgumentError, "Missing the required parameter 'repository_sign' when calling RepositoriesContainerPushApi.sign" end # resource path local_var_path = '{container_container_push_repository_href}sign/'.sub('{' + 'container_container_push_repository_href' + '}', CGI.escape(container_container_push_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(repository_sign) # return_type return_type = opts[:debug_return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"RepositoriesContainerPushApi.sign", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerPushApi#sign\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#tag(container_container_push_repository_href, tag_image, opts = {}) ⇒ AsyncOperationResponse
Create a Tag Trigger an asynchronous task to tag an image in the repository
883 884 885 886 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 883 def tag(container_container_push_repository_href, tag_image, opts = {}) data, _status_code, _headers = tag_with_http_info(container_container_push_repository_href, tag_image, opts) data end |
#tag_with_http_info(container_container_push_repository_href, tag_image, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Create a Tag Trigger an asynchronous task to tag an image in the repository
895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 895 def tag_with_http_info(container_container_push_repository_href, tag_image, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerPushApi.tag ...' end # verify the required parameter 'container_container_push_repository_href' is set if @api_client.config.client_side_validation && container_container_push_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_container_push_repository_href' when calling RepositoriesContainerPushApi.tag" end # verify the required parameter 'tag_image' is set if @api_client.config.client_side_validation && tag_image.nil? fail ArgumentError, "Missing the required parameter 'tag_image' when calling RepositoriesContainerPushApi.tag" end # resource path local_var_path = '{container_container_push_repository_href}tag/'.sub('{' + 'container_container_push_repository_href' + '}', CGI.escape(container_container_push_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(tag_image) # return_type return_type = opts[:debug_return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"RepositoriesContainerPushApi.tag", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerPushApi#tag\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#untag(container_container_push_repository_href, un_tag_image, opts = {}) ⇒ AsyncOperationResponse
Delete a tag Trigger an asynchronous task to untag an image in the repository
960 961 962 963 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 960 def untag(container_container_push_repository_href, un_tag_image, opts = {}) data, _status_code, _headers = untag_with_http_info(container_container_push_repository_href, un_tag_image, opts) data end |
#untag_with_http_info(container_container_push_repository_href, un_tag_image, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Delete a tag Trigger an asynchronous task to untag an image in the repository
972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 972 def untag_with_http_info(container_container_push_repository_href, un_tag_image, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerPushApi.untag ...' end # verify the required parameter 'container_container_push_repository_href' is set if @api_client.config.client_side_validation && container_container_push_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_container_push_repository_href' when calling RepositoriesContainerPushApi.untag" end # verify the required parameter 'un_tag_image' is set if @api_client.config.client_side_validation && un_tag_image.nil? fail ArgumentError, "Missing the required parameter 'un_tag_image' when calling RepositoriesContainerPushApi.untag" end # resource path local_var_path = '{container_container_push_repository_href}untag/'.sub('{' + 'container_container_push_repository_href' + '}', CGI.escape(container_container_push_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(un_tag_image) # return_type return_type = opts[:debug_return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"RepositoriesContainerPushApi.untag", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerPushApi#untag\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update(container_container_push_repository_href, container_container_push_repository, opts = {}) ⇒ ContainerContainerPushRepositoryResponse
Update a container push repository Update the entity and trigger an asynchronous task if necessary
1037 1038 1039 1040 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 1037 def update(container_container_push_repository_href, container_container_push_repository, opts = {}) data, _status_code, _headers = update_with_http_info(container_container_push_repository_href, container_container_push_repository, opts) data end |
#update_with_http_info(container_container_push_repository_href, container_container_push_repository, opts = {}) ⇒ Array<(ContainerContainerPushRepositoryResponse, Integer, Hash)>
Update a container push repository Update the entity and trigger an asynchronous task if necessary
1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 1049 def update_with_http_info(container_container_push_repository_href, container_container_push_repository, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerPushApi.update ...' end # verify the required parameter 'container_container_push_repository_href' is set if @api_client.config.client_side_validation && container_container_push_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_container_push_repository_href' when calling RepositoriesContainerPushApi.update" end # verify the required parameter 'container_container_push_repository' is set if @api_client.config.client_side_validation && container_container_push_repository.nil? fail ArgumentError, "Missing the required parameter 'container_container_push_repository' when calling RepositoriesContainerPushApi.update" end # resource path local_var_path = '{container_container_push_repository_href}'.sub('{' + 'container_container_push_repository_href' + '}', CGI.escape(container_container_push_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(container_container_push_repository) # return_type return_type = opts[:debug_return_type] || 'ContainerContainerPushRepositoryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"RepositoriesContainerPushApi.update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerPushApi#update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |