Method: PulpContainerClient::ContainerContainerDistribution#list_invalid_properties
- Defined in:
- lib/pulp_container_client/models/container_container_distribution.rb
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/pulp_container_client/models/container_container_distribution.rb', line 151 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @base_path.nil? invalid_properties.push('invalid value for "base_path", base_path cannot be nil.') end if @base_path.to_s.length < 1 invalid_properties.push('invalid value for "base_path", the character length must be great than or equal to 1.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be great than or equal to 1.') end if !@description.nil? && @description.to_s.length < 1 invalid_properties.push('invalid value for "description", the character length must be great than or equal to 1.') end invalid_properties end |