Class: PulpContainerClient::ContainerManifestResponse
- Inherits:
-
Object
- Object
- PulpContainerClient::ContainerManifestResponse
- Defined in:
- lib/pulp_container_client/models/container_manifest_response.rb
Overview
Serializer for Manifests.
Instance Attribute Summary collapse
-
#annotations ⇒ Object
Property that contains arbitrary metadata stored inside the image manifest.
-
#artifact ⇒ Object
Artifact file representing the physical content.
-
#blobs ⇒ Object
Blobs that are referenced by this Manifest.
-
#config_blob ⇒ Object
Blob that contains configuration for this Manifest.
-
#digest ⇒ Object
sha256 of the Manifest file.
-
#is_bootable ⇒ Object
A boolean determining whether users can boot from an image or not.
-
#is_flatpak ⇒ Object
A boolean determining whether the image bundles a Flatpak application.
-
#labels ⇒ Object
Property describing metadata stored inside the image configuration.
-
#listed_manifests ⇒ Object
Manifests that are referenced by this Manifest List.
-
#media_type ⇒ Object
Manifest media type of the file.
-
#pulp_created ⇒ Object
Timestamp of creation.
-
#pulp_href ⇒ Object
Returns the value of attribute pulp_href.
-
#pulp_last_updated ⇒ Object
Timestamp of the last time this resource was updated.
-
#schema_version ⇒ Object
Manifest schema version.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ContainerManifestResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ContainerManifestResponse
Initializes the object
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 107 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PulpContainerClient::ContainerManifestResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PulpContainerClient::ContainerManifestResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pulp_href') self.pulp_href = attributes[:'pulp_href'] end if attributes.key?(:'pulp_created') self.pulp_created = attributes[:'pulp_created'] end if attributes.key?(:'pulp_last_updated') self.pulp_last_updated = attributes[:'pulp_last_updated'] end if attributes.key?(:'artifact') self.artifact = attributes[:'artifact'] end if attributes.key?(:'digest') self.digest = attributes[:'digest'] end if attributes.key?(:'schema_version') self.schema_version = attributes[:'schema_version'] end if attributes.key?(:'media_type') self.media_type = attributes[:'media_type'] end if attributes.key?(:'listed_manifests') if (value = attributes[:'listed_manifests']).is_a?(Array) self.listed_manifests = value end end if attributes.key?(:'config_blob') self.config_blob = attributes[:'config_blob'] end if attributes.key?(:'blobs') if (value = attributes[:'blobs']).is_a?(Array) self.blobs = value end end if attributes.key?(:'annotations') self.annotations = attributes[:'annotations'] end if attributes.key?(:'labels') self.labels = attributes[:'labels'] end if attributes.key?(:'is_bootable') self.is_bootable = attributes[:'is_bootable'] else self.is_bootable = false end if attributes.key?(:'is_flatpak') self.is_flatpak = attributes[:'is_flatpak'] else self.is_flatpak = false end end |
Instance Attribute Details
#annotations ⇒ Object
Property that contains arbitrary metadata stored inside the image manifest.
48 49 50 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 48 def annotations @annotations end |
#artifact ⇒ Object
Artifact file representing the physical content
27 28 29 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 27 def artifact @artifact end |
#blobs ⇒ Object
Blobs that are referenced by this Manifest
45 46 47 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 45 def blobs @blobs end |
#config_blob ⇒ Object
Blob that contains configuration for this Manifest
42 43 44 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 42 def config_blob @config_blob end |
#digest ⇒ Object
sha256 of the Manifest file
30 31 32 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 30 def digest @digest end |
#is_bootable ⇒ Object
A boolean determining whether users can boot from an image or not.
54 55 56 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 54 def is_bootable @is_bootable end |
#is_flatpak ⇒ Object
A boolean determining whether the image bundles a Flatpak application
57 58 59 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 57 def is_flatpak @is_flatpak end |
#labels ⇒ Object
Property describing metadata stored inside the image configuration
51 52 53 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 51 def labels @labels end |
#listed_manifests ⇒ Object
Manifests that are referenced by this Manifest List
39 40 41 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 39 def listed_manifests @listed_manifests end |
#media_type ⇒ Object
Manifest media type of the file
36 37 38 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 36 def media_type @media_type end |
#pulp_created ⇒ Object
Timestamp of creation.
21 22 23 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 21 def pulp_created @pulp_created end |
#pulp_href ⇒ Object
Returns the value of attribute pulp_href.
18 19 20 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 18 def pulp_href @pulp_href end |
#pulp_last_updated ⇒ Object
Timestamp of the last time this resource was updated. Note: for immutable resources - like content, repository versions, and publication - pulp_created and pulp_last_updated dates will be the same.
24 25 26 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 24 def pulp_last_updated @pulp_last_updated end |
#schema_version ⇒ Object
Manifest schema version
33 34 35 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 33 def schema_version @schema_version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 60 def self.attribute_map { :'pulp_href' => :'pulp_href', :'pulp_created' => :'pulp_created', :'pulp_last_updated' => :'pulp_last_updated', :'artifact' => :'artifact', :'digest' => :'digest', :'schema_version' => :'schema_version', :'media_type' => :'media_type', :'listed_manifests' => :'listed_manifests', :'config_blob' => :'config_blob', :'blobs' => :'blobs', :'annotations' => :'annotations', :'labels' => :'labels', :'is_bootable' => :'is_bootable', :'is_flatpak' => :'is_flatpak' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
264 265 266 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 264 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
100 101 102 103 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 100 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 80 def self.openapi_types { :'pulp_href' => :'String', :'pulp_created' => :'DateTime', :'pulp_last_updated' => :'DateTime', :'artifact' => :'String', :'digest' => :'String', :'schema_version' => :'Integer', :'media_type' => :'String', :'listed_manifests' => :'Array<String>', :'config_blob' => :'String', :'blobs' => :'Array<String>', :'annotations' => :'AnyType', :'labels' => :'AnyType', :'is_bootable' => :'Boolean', :'is_flatpak' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 230 def ==(o) return true if self.equal?(o) self.class == o.class && pulp_href == o.pulp_href && pulp_created == o.pulp_created && pulp_last_updated == o.pulp_last_updated && artifact == o.artifact && digest == o.digest && schema_version == o.schema_version && media_type == o.media_type && listed_manifests == o.listed_manifests && config_blob == o.config_blob && blobs == o.blobs && annotations == o.annotations && labels == o.labels && is_bootable == o.is_bootable && is_flatpak == o.is_flatpak end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 292 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model PulpContainerClient.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 361 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 271 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
251 252 253 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 251 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
257 258 259 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 257 def hash [pulp_href, pulp_created, pulp_last_updated, artifact, digest, schema_version, media_type, listed_manifests, config_blob, blobs, annotations, labels, is_bootable, is_flatpak].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 187 def list_invalid_properties invalid_properties = Array.new if @artifact.nil? invalid_properties.push('invalid value for "artifact", artifact cannot be nil.') end if @digest.nil? invalid_properties.push('invalid value for "digest", digest cannot be nil.') end if @schema_version.nil? invalid_properties.push('invalid value for "schema_version", schema_version cannot be nil.') end if @media_type.nil? invalid_properties.push('invalid value for "media_type", media_type cannot be nil.') end if @listed_manifests.nil? invalid_properties.push('invalid value for "listed_manifests", listed_manifests cannot be nil.') end if @blobs.nil? invalid_properties.push('invalid value for "blobs", blobs cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
337 338 339 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 337 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 343 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
331 332 333 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 331 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
218 219 220 221 222 223 224 225 226 |
# File 'lib/pulp_container_client/models/container_manifest_response.rb', line 218 def valid? return false if @artifact.nil? return false if @digest.nil? return false if @schema_version.nil? return false if @media_type.nil? return false if @listed_manifests.nil? return false if @blobs.nil? true end |