Class: PulpContainerClient::RepositoriesContainerPushApi
- Inherits:
-
Object
- Object
- PulpContainerClient::RepositoriesContainerPushApi
- Defined in:
- lib/pulp_container_client/api/repositories_container_push_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#add_role(container_container_push_repository_href, nested_role, opts = {}) ⇒ NestedRoleResponse
Add a role for this object to users/groups.
-
#add_role_with_http_info(container_container_push_repository_href, nested_role, opts = {}) ⇒ Array<(NestedRoleResponse, Integer, Hash)>
Add a role for this object to users/groups.
-
#initialize(api_client = ApiClient.default) ⇒ RepositoriesContainerPushApi
constructor
A new instance of RepositoriesContainerPushApi.
-
#list(opts = {}) ⇒ PaginatedcontainerContainerPushRepositoryResponseList
List container push repositorys ViewSet for a container push repository.
-
#list_roles(container_container_push_repository_href, opts = {}) ⇒ ObjectRolesResponse
List roles assigned to this object.
-
#list_roles_with_http_info(container_container_push_repository_href, opts = {}) ⇒ Array<(ObjectRolesResponse, Integer, Hash)>
List roles assigned to this object.
-
#list_with_http_info(opts = {}) ⇒ Array<(PaginatedcontainerContainerPushRepositoryResponseList, Integer, Hash)>
List container push repositorys ViewSet for a container push repository.
-
#my_permissions(container_container_push_repository_href, opts = {}) ⇒ MyPermissionsResponse
List permissions available to the current user on this object.
-
#my_permissions_with_http_info(container_container_push_repository_href, opts = {}) ⇒ Array<(MyPermissionsResponse, Integer, Hash)>
List permissions available to the current user on this object.
-
#partial_update(container_container_push_repository_href, patchedcontainer_container_push_repository, opts = {}) ⇒ AsyncOperationResponse
Update a container push repository Trigger an asynchronous partial update task.
-
#partial_update_with_http_info(container_container_push_repository_href, patchedcontainer_container_push_repository, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Update a container push repository Trigger an asynchronous partial update task.
-
#read(container_container_push_repository_href, opts = {}) ⇒ ContainerContainerPushRepositoryResponse
Inspect a container push repository ViewSet for a container push repository.
-
#read_with_http_info(container_container_push_repository_href, opts = {}) ⇒ Array<(ContainerContainerPushRepositoryResponse, Integer, Hash)>
Inspect a container push repository ViewSet for a container push repository.
-
#remove_image(container_container_push_repository_href, remove_image, opts = {}) ⇒ AsyncOperationResponse
Delete an image from a repository Trigger an asynchronous task to remove a manifest and all its associated data by a digest.
-
#remove_image_with_http_info(container_container_push_repository_href, remove_image, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Delete an image from a repository Trigger an asynchronous task to remove a manifest and all its associated data by a digest.
-
#remove_role(container_container_push_repository_href, nested_role, opts = {}) ⇒ NestedRoleResponse
Remove a role for this object from users/groups.
-
#remove_role_with_http_info(container_container_push_repository_href, nested_role, opts = {}) ⇒ Array<(NestedRoleResponse, Integer, Hash)>
Remove a role for this object from users/groups.
-
#remove_signatures(container_container_push_repository_href, remove_signatures, opts = {}) ⇒ RemoveSignaturesResponse
Create a task which deletes signatures by the passed key_id.
-
#remove_signatures_with_http_info(container_container_push_repository_href, remove_signatures, opts = {}) ⇒ Array<(RemoveSignaturesResponse, Integer, Hash)>
Create a task which deletes signatures by the passed key_id.
-
#sign(container_container_push_repository_href, repository_sign, opts = {}) ⇒ AsyncOperationResponse
Sign images in the repo Trigger an asynchronous task to sign content.
-
#sign_with_http_info(container_container_push_repository_href, repository_sign, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Sign images in the repo Trigger an asynchronous task to sign content.
-
#tag(container_container_push_repository_href, tag_image, opts = {}) ⇒ AsyncOperationResponse
Create a Tag Trigger an asynchronous task to tag an image in the repository.
-
#tag_with_http_info(container_container_push_repository_href, tag_image, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Create a Tag Trigger an asynchronous task to tag an image in the repository.
-
#untag(container_container_push_repository_href, un_tag_image, opts = {}) ⇒ AsyncOperationResponse
Delete a tag Trigger an asynchronous task to untag an image in the repository.
-
#untag_with_http_info(container_container_push_repository_href, un_tag_image, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Delete a tag Trigger an asynchronous task to untag an image in the repository.
-
#update(container_container_push_repository_href, container_container_push_repository, opts = {}) ⇒ AsyncOperationResponse
Update a container push repository Trigger an asynchronous update task.
-
#update_with_http_info(container_container_push_repository_href, container_container_push_repository, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Update a container push repository Trigger an asynchronous update task.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ RepositoriesContainerPushApi
Returns a new instance of RepositoriesContainerPushApi.
19 20 21 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#add_role(container_container_push_repository_href, nested_role, opts = {}) ⇒ NestedRoleResponse
Add a role for this object to users/groups.
27 28 29 30 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 27 def add_role(container_container_push_repository_href, nested_role, opts = {}) data, _status_code, _headers = add_role_with_http_info(container_container_push_repository_href, nested_role, opts) data end |
#add_role_with_http_info(container_container_push_repository_href, nested_role, opts = {}) ⇒ Array<(NestedRoleResponse, Integer, Hash)>
Add a role for this object to users/groups.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 37 def add_role_with_http_info(container_container_push_repository_href, nested_role, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerPushApi.add_role ...' end # verify the required parameter 'container_container_push_repository_href' is set if @api_client.config.client_side_validation && container_container_push_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_container_push_repository_href' when calling RepositoriesContainerPushApi.add_role" end # verify the required parameter 'nested_role' is set if @api_client.config.client_side_validation && nested_role.nil? fail ArgumentError, "Missing the required parameter 'nested_role' when calling RepositoriesContainerPushApi.add_role" end # resource path local_var_path = '{container_container_push_repository_href}add_role/'.sub('{' + 'container_container_push_repository_href' + '}', CGI.escape(container_container_push_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(nested_role) # return_type return_type = opts[:return_type] || 'NestedRoleResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerPushApi#add_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list(opts = {}) ⇒ PaginatedcontainerContainerPushRepositoryResponseList
List container push repositorys ViewSet for a container push repository. POST and DELETE are disallowed because a push repository is tightly coupled with a ContainerDistribution which handles it automatically. Created - during push operation, removed - with ContainerDistribution removal.
105 106 107 108 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 105 def list(opts = {}) data, _status_code, _headers = list_with_http_info(opts) data end |
#list_roles(container_container_push_repository_href, opts = {}) ⇒ ObjectRolesResponse
List roles assigned to this object.
185 186 187 188 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 185 def list_roles(container_container_push_repository_href, opts = {}) data, _status_code, _headers = list_roles_with_http_info(container_container_push_repository_href, opts) data end |
#list_roles_with_http_info(container_container_push_repository_href, opts = {}) ⇒ Array<(ObjectRolesResponse, Integer, Hash)>
List roles assigned to this object.
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 196 def list_roles_with_http_info(container_container_push_repository_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerPushApi.list_roles ...' end # verify the required parameter 'container_container_push_repository_href' is set if @api_client.config.client_side_validation && container_container_push_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_container_push_repository_href' when calling RepositoriesContainerPushApi.list_roles" end # resource path local_var_path = '{container_container_push_repository_href}list_roles/'.sub('{' + 'container_container_push_repository_href' + '}', CGI.escape(container_container_push_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = opts[:'fields'] if !opts[:'fields'].nil? query_params[:'exclude_fields'] = opts[:'exclude_fields'] if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'ObjectRolesResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerPushApi#list_roles\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_with_http_info(opts = {}) ⇒ Array<(PaginatedcontainerContainerPushRepositoryResponseList, Integer, Hash)>
List container push repositorys ViewSet for a container push repository. POST and DELETE are disallowed because a push repository is tightly coupled with a ContainerDistribution which handles it automatically. Created - during push operation, removed - with ContainerDistribution removal.
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 125 def list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerPushApi.list ...' end # resource path local_var_path = '/pulp/api/v3/repositories/container/container-push/' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil? query_params[:'name__contains'] = opts[:'name__contains'] if !opts[:'name__contains'].nil? query_params[:'name__icontains'] = opts[:'name__icontains'] if !opts[:'name__icontains'].nil? query_params[:'name__in'] = @api_client.build_collection_param(opts[:'name__in'], :csv) if !opts[:'name__in'].nil? query_params[:'name__startswith'] = opts[:'name__startswith'] if !opts[:'name__startswith'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'ordering'] = opts[:'ordering'] if !opts[:'ordering'].nil? query_params[:'pulp_label_select'] = opts[:'pulp_label_select'] if !opts[:'pulp_label_select'].nil? query_params[:'fields'] = opts[:'fields'] if !opts[:'fields'].nil? query_params[:'exclude_fields'] = opts[:'exclude_fields'] if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'PaginatedcontainerContainerPushRepositoryResponseList' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerPushApi#list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#my_permissions(container_container_push_repository_href, opts = {}) ⇒ MyPermissionsResponse
List permissions available to the current user on this object.
251 252 253 254 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 251 def (container_container_push_repository_href, opts = {}) data, _status_code, _headers = (container_container_push_repository_href, opts) data end |
#my_permissions_with_http_info(container_container_push_repository_href, opts = {}) ⇒ Array<(MyPermissionsResponse, Integer, Hash)>
List permissions available to the current user on this object.
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 262 def (container_container_push_repository_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerPushApi.my_permissions ...' end # verify the required parameter 'container_container_push_repository_href' is set if @api_client.config.client_side_validation && container_container_push_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_container_push_repository_href' when calling RepositoriesContainerPushApi.my_permissions" end # resource path local_var_path = '{container_container_push_repository_href}my_permissions/'.sub('{' + 'container_container_push_repository_href' + '}', CGI.escape(container_container_push_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = opts[:'fields'] if !opts[:'fields'].nil? query_params[:'exclude_fields'] = opts[:'exclude_fields'] if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'MyPermissionsResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerPushApi#my_permissions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#partial_update(container_container_push_repository_href, patchedcontainer_container_push_repository, opts = {}) ⇒ AsyncOperationResponse
Update a container push repository Trigger an asynchronous partial update task
317 318 319 320 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 317 def partial_update(container_container_push_repository_href, patchedcontainer_container_push_repository, opts = {}) data, _status_code, _headers = partial_update_with_http_info(container_container_push_repository_href, patchedcontainer_container_push_repository, opts) data end |
#partial_update_with_http_info(container_container_push_repository_href, patchedcontainer_container_push_repository, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Update a container push repository Trigger an asynchronous partial update task
328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 328 def partial_update_with_http_info(container_container_push_repository_href, patchedcontainer_container_push_repository, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerPushApi.partial_update ...' end # verify the required parameter 'container_container_push_repository_href' is set if @api_client.config.client_side_validation && container_container_push_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_container_push_repository_href' when calling RepositoriesContainerPushApi.partial_update" end # verify the required parameter 'patchedcontainer_container_push_repository' is set if @api_client.config.client_side_validation && patchedcontainer_container_push_repository.nil? fail ArgumentError, "Missing the required parameter 'patchedcontainer_container_push_repository' when calling RepositoriesContainerPushApi.partial_update" end # resource path local_var_path = '{container_container_push_repository_href}'.sub('{' + 'container_container_push_repository_href' + '}', CGI.escape(container_container_push_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(patchedcontainer_container_push_repository) # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerPushApi#partial_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#read(container_container_push_repository_href, opts = {}) ⇒ ContainerContainerPushRepositoryResponse
Inspect a container push repository ViewSet for a container push repository. POST and DELETE are disallowed because a push repository is tightly coupled with a ContainerDistribution which handles it automatically. Created - during push operation, removed - with ContainerDistribution removal.
388 389 390 391 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 388 def read(container_container_push_repository_href, opts = {}) data, _status_code, _headers = read_with_http_info(container_container_push_repository_href, opts) data end |
#read_with_http_info(container_container_push_repository_href, opts = {}) ⇒ Array<(ContainerContainerPushRepositoryResponse, Integer, Hash)>
Inspect a container push repository ViewSet for a container push repository. POST and DELETE are disallowed because a push repository is tightly coupled with a ContainerDistribution which handles it automatically. Created - during push operation, removed - with ContainerDistribution removal.
400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 400 def read_with_http_info(container_container_push_repository_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerPushApi.read ...' end # verify the required parameter 'container_container_push_repository_href' is set if @api_client.config.client_side_validation && container_container_push_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_container_push_repository_href' when calling RepositoriesContainerPushApi.read" end # resource path local_var_path = '{container_container_push_repository_href}'.sub('{' + 'container_container_push_repository_href' + '}', CGI.escape(container_container_push_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = opts[:'fields'] if !opts[:'fields'].nil? query_params[:'exclude_fields'] = opts[:'exclude_fields'] if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'ContainerContainerPushRepositoryResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerPushApi#read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#remove_image(container_container_push_repository_href, remove_image, opts = {}) ⇒ AsyncOperationResponse
Delete an image from a repository Trigger an asynchronous task to remove a manifest and all its associated data by a digest
455 456 457 458 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 455 def remove_image(container_container_push_repository_href, remove_image, opts = {}) data, _status_code, _headers = remove_image_with_http_info(container_container_push_repository_href, remove_image, opts) data end |
#remove_image_with_http_info(container_container_push_repository_href, remove_image, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Delete an image from a repository Trigger an asynchronous task to remove a manifest and all its associated data by a digest
466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 466 def remove_image_with_http_info(container_container_push_repository_href, remove_image, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerPushApi.remove_image ...' end # verify the required parameter 'container_container_push_repository_href' is set if @api_client.config.client_side_validation && container_container_push_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_container_push_repository_href' when calling RepositoriesContainerPushApi.remove_image" end # verify the required parameter 'remove_image' is set if @api_client.config.client_side_validation && remove_image.nil? fail ArgumentError, "Missing the required parameter 'remove_image' when calling RepositoriesContainerPushApi.remove_image" end # resource path local_var_path = '{container_container_push_repository_href}remove_image/'.sub('{' + 'container_container_push_repository_href' + '}', CGI.escape(container_container_push_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(remove_image) # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerPushApi#remove_image\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#remove_role(container_container_push_repository_href, nested_role, opts = {}) ⇒ NestedRoleResponse
Remove a role for this object from users/groups.
524 525 526 527 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 524 def remove_role(container_container_push_repository_href, nested_role, opts = {}) data, _status_code, _headers = remove_role_with_http_info(container_container_push_repository_href, nested_role, opts) data end |
#remove_role_with_http_info(container_container_push_repository_href, nested_role, opts = {}) ⇒ Array<(NestedRoleResponse, Integer, Hash)>
Remove a role for this object from users/groups.
534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 534 def remove_role_with_http_info(container_container_push_repository_href, nested_role, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerPushApi.remove_role ...' end # verify the required parameter 'container_container_push_repository_href' is set if @api_client.config.client_side_validation && container_container_push_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_container_push_repository_href' when calling RepositoriesContainerPushApi.remove_role" end # verify the required parameter 'nested_role' is set if @api_client.config.client_side_validation && nested_role.nil? fail ArgumentError, "Missing the required parameter 'nested_role' when calling RepositoriesContainerPushApi.remove_role" end # resource path local_var_path = '{container_container_push_repository_href}remove_role/'.sub('{' + 'container_container_push_repository_href' + '}', CGI.escape(container_container_push_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(nested_role) # return_type return_type = opts[:return_type] || 'NestedRoleResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerPushApi#remove_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#remove_signatures(container_container_push_repository_href, remove_signatures, opts = {}) ⇒ RemoveSignaturesResponse
Create a task which deletes signatures by the passed key_id.
592 593 594 595 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 592 def remove_signatures(container_container_push_repository_href, remove_signatures, opts = {}) data, _status_code, _headers = remove_signatures_with_http_info(container_container_push_repository_href, remove_signatures, opts) data end |
#remove_signatures_with_http_info(container_container_push_repository_href, remove_signatures, opts = {}) ⇒ Array<(RemoveSignaturesResponse, Integer, Hash)>
Create a task which deletes signatures by the passed key_id.
602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 602 def remove_signatures_with_http_info(container_container_push_repository_href, remove_signatures, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerPushApi.remove_signatures ...' end # verify the required parameter 'container_container_push_repository_href' is set if @api_client.config.client_side_validation && container_container_push_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_container_push_repository_href' when calling RepositoriesContainerPushApi.remove_signatures" end # verify the required parameter 'remove_signatures' is set if @api_client.config.client_side_validation && remove_signatures.nil? fail ArgumentError, "Missing the required parameter 'remove_signatures' when calling RepositoriesContainerPushApi.remove_signatures" end # resource path local_var_path = '{container_container_push_repository_href}remove_signatures/'.sub('{' + 'container_container_push_repository_href' + '}', CGI.escape(container_container_push_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(remove_signatures) # return_type return_type = opts[:return_type] || 'RemoveSignaturesResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerPushApi#remove_signatures\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#sign(container_container_push_repository_href, repository_sign, opts = {}) ⇒ AsyncOperationResponse
Sign images in the repo Trigger an asynchronous task to sign content.
661 662 663 664 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 661 def sign(container_container_push_repository_href, repository_sign, opts = {}) data, _status_code, _headers = sign_with_http_info(container_container_push_repository_href, repository_sign, opts) data end |
#sign_with_http_info(container_container_push_repository_href, repository_sign, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Sign images in the repo Trigger an asynchronous task to sign content.
672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 672 def sign_with_http_info(container_container_push_repository_href, repository_sign, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerPushApi.sign ...' end # verify the required parameter 'container_container_push_repository_href' is set if @api_client.config.client_side_validation && container_container_push_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_container_push_repository_href' when calling RepositoriesContainerPushApi.sign" end # verify the required parameter 'repository_sign' is set if @api_client.config.client_side_validation && repository_sign.nil? fail ArgumentError, "Missing the required parameter 'repository_sign' when calling RepositoriesContainerPushApi.sign" end # resource path local_var_path = '{container_container_push_repository_href}sign/'.sub('{' + 'container_container_push_repository_href' + '}', CGI.escape(container_container_push_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(repository_sign) # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerPushApi#sign\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#tag(container_container_push_repository_href, tag_image, opts = {}) ⇒ AsyncOperationResponse
Create a Tag Trigger an asynchronous task to tag an image in the repository
731 732 733 734 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 731 def tag(container_container_push_repository_href, tag_image, opts = {}) data, _status_code, _headers = tag_with_http_info(container_container_push_repository_href, tag_image, opts) data end |
#tag_with_http_info(container_container_push_repository_href, tag_image, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Create a Tag Trigger an asynchronous task to tag an image in the repository
742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 742 def tag_with_http_info(container_container_push_repository_href, tag_image, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerPushApi.tag ...' end # verify the required parameter 'container_container_push_repository_href' is set if @api_client.config.client_side_validation && container_container_push_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_container_push_repository_href' when calling RepositoriesContainerPushApi.tag" end # verify the required parameter 'tag_image' is set if @api_client.config.client_side_validation && tag_image.nil? fail ArgumentError, "Missing the required parameter 'tag_image' when calling RepositoriesContainerPushApi.tag" end # resource path local_var_path = '{container_container_push_repository_href}tag/'.sub('{' + 'container_container_push_repository_href' + '}', CGI.escape(container_container_push_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(tag_image) # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerPushApi#tag\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#untag(container_container_push_repository_href, un_tag_image, opts = {}) ⇒ AsyncOperationResponse
Delete a tag Trigger an asynchronous task to untag an image in the repository
801 802 803 804 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 801 def untag(container_container_push_repository_href, un_tag_image, opts = {}) data, _status_code, _headers = untag_with_http_info(container_container_push_repository_href, un_tag_image, opts) data end |
#untag_with_http_info(container_container_push_repository_href, un_tag_image, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Delete a tag Trigger an asynchronous task to untag an image in the repository
812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 812 def untag_with_http_info(container_container_push_repository_href, un_tag_image, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerPushApi.untag ...' end # verify the required parameter 'container_container_push_repository_href' is set if @api_client.config.client_side_validation && container_container_push_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_container_push_repository_href' when calling RepositoriesContainerPushApi.untag" end # verify the required parameter 'un_tag_image' is set if @api_client.config.client_side_validation && un_tag_image.nil? fail ArgumentError, "Missing the required parameter 'un_tag_image' when calling RepositoriesContainerPushApi.untag" end # resource path local_var_path = '{container_container_push_repository_href}untag/'.sub('{' + 'container_container_push_repository_href' + '}', CGI.escape(container_container_push_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(un_tag_image) # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerPushApi#untag\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update(container_container_push_repository_href, container_container_push_repository, opts = {}) ⇒ AsyncOperationResponse
Update a container push repository Trigger an asynchronous update task
871 872 873 874 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 871 def update(container_container_push_repository_href, container_container_push_repository, opts = {}) data, _status_code, _headers = update_with_http_info(container_container_push_repository_href, container_container_push_repository, opts) data end |
#update_with_http_info(container_container_push_repository_href, container_container_push_repository, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Update a container push repository Trigger an asynchronous update task
882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 |
# File 'lib/pulp_container_client/api/repositories_container_push_api.rb', line 882 def update_with_http_info(container_container_push_repository_href, container_container_push_repository, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesContainerPushApi.update ...' end # verify the required parameter 'container_container_push_repository_href' is set if @api_client.config.client_side_validation && container_container_push_repository_href.nil? fail ArgumentError, "Missing the required parameter 'container_container_push_repository_href' when calling RepositoriesContainerPushApi.update" end # verify the required parameter 'container_container_push_repository' is set if @api_client.config.client_side_validation && container_container_push_repository.nil? fail ArgumentError, "Missing the required parameter 'container_container_push_repository' when calling RepositoriesContainerPushApi.update" end # resource path local_var_path = '{container_container_push_repository_href}'.sub('{' + 'container_container_push_repository_href' + '}', CGI.escape(container_container_push_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(container_container_push_repository) # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesContainerPushApi#update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |